rm(list = ls())

library(psych)
library(Rcmdr)

library(lme4)

library(languageR)

data400550 <- read.table("Fenster/400_550.tab",header=T)

data300600 <- read.table("Fenster/300_600.tab",header=T)

with(data300600,tapply(mean,cond,mean))

data <- read.table("600_800.tab",header=T)


xtabs(~subj+cond,data)


## critical channels
critc <- c("F3","FZ","F4","C3","CZ","C4","P3","PZ","P4")

## frontals:
frontc <- c("F3","FZ","F4")

## central:
centralc <- c("C3","CZ","C4")

# posterior:
postc <- c("P3","PZ","P4")

d <- subset(data,chan%in%critc)

d400550 <- subset(data,chan%in%critc)

data$cond<-as.factor(data$cond)

d$cond<-as.factor(d$cond)

plotMeans(data$mean, data$chan, data$cond, error.bars="conf.int",  level=0.95)

numSummary(data[,"mean"], groups=data$cond, statistics=c("mean", "sd", "quantiles"))


###########################################

head(data)

summary(data)

str(data)

qq.plot(data$mean, dist= "norm", labels=FALSE)

datan <- subset(data, chan=="F3" |chan=="FZ" |chan=="F4" |chan=="C3" |chan=="CZ" |chan=="C4" |chan=="P3" |chan=="PZ" |chan=="P4")

datan400550 <- subset(data400550, chan=="F3" |chan=="FZ" |chan=="F4" |chan=="C3" |chan=="CZ" |chan=="C4" |chan=="P3" |chan=="PZ" |chan=="P4")

datan$chan<-factor(datan$chan)
datan400550$chan<-factor(datan400550$chan)

head(datan)
head(datan400550)

str(datan)

datan$roi <- recode(datan$chan, '"F3"= "ant"; "FZ"= "ant"; "F4"= "ant"; "P3"= "pos"; "PZ"= "pos"; "P4"= "pos"; "C3"= "mid"; "CZ"= "mid"; "C4"= "mid"')

str(datan)

numSummary(datan[,"mean"], groups=datan$cond, statistics=c("mean", "sd", "quantiles"))

numSummary(datan[,"mean"], groups=datan$roi, statistics=c("mean", "sd", "quantiles"))


numSummary(subset(datan,roi=="ant")[,"mean"], groups=subset(datan,roi=="ant")$cond, statistics=c("mean", "sd", "quantiles"))

numSummary(subset(datan,roi=="mid")[,"mean"], groups=subset(datan,roi=="mid")$cond, statistics=c("mean", "sd", "quantiles"))

numSummary(subset(datan,roi=="pos")[,"mean"], groups=subset(datan,roi=="pos")$cond, statistics=c("mean", "sd", "quantiles"))


#Mittelwerte
(means.erp <- with(datan,
                   tapply(mean,IND=list(cond, roi),mean)))
                   
#Varianz
(means.var.erp <- with(datan,
                   tapply(mean,IND=list(cond, roi),var)))                  

#Standardabweichung
(means.sd.erp <- with(datan,
                   tapply(mean,IND=list(cond, roi),sd)))
                   

                   
#Standardfehler
(sqrt(var(datan$mean) / length(datan$mean)))
                 
#Konfidenzintervall
                   
mean(datan$mean) + 1.96 * sqrt(var(datan$mean) / length(datan$mean))
mean(datan$mean) - 1.96 * sqrt(var(datan$mean) / length(datan$mean))


datan$AB <- ifelse(datan$cond=="101", -1,
               ifelse(datan$cond=="102", 1, 0))
               

datan$CD <- ifelse(datan$cond=="103", -1,
               ifelse(datan$cond=="104", 1, 0))
               

datan$IJ <- ifelse(datan$cond=="109", -1,
               ifelse(datan$cond=="110", 1, 0))


datan400550$AB <- ifelse(datan400550$cond=="101", -1,
               ifelse(datan400550$cond=="102", 1, 0))
               

datan400550$CD <- ifelse(datan400550$cond=="103", -1,
               ifelse(datan400550$cond=="104", 1, 0))
               

datan400550$IJ <- ifelse(datan400550$cond=="109", -1,
               ifelse(datan400550$cond=="110", 1, 0))


       # A B  C D  I J
#AB     -1 1  0 0  0 0
#CD      0 0 -1 1  0 0
#IJ      0 0  0 0 -1 1

summary(datan)


library(lattice)

coplot(mean~cond|subj,
        panel=function(x,y,...) {
              panel.smooth(x,y,span=.8,iter=5,...)
              },
       subset(datan,roi=="ant"))


coplot(mean~cond|subj,
        panel=function(x,y,...) {
              panel.smooth(x,y,span=.8,iter=5,...)
              },
       subset(datan,roi=="mid"))

coplot(mean~cond|subj,
        panel=function(x,y,...) {
              panel.smooth(x,y,span=.8,iter=5,...)
              },
       subset(datan,roi=="pos"))


with(datan,tapply(mean,IND=list(factor(AB)),mean))
with(datan,tapply(mean,IND=list(factor(CD)),mean))
with(datan,tapply(mean,IND=list(factor(IJ)),mean))

## clefts:
library(lme4)

lmer(mean~AB+CD+IJ+(1+AB+CD+IJ|subj),datan400550)

with(datan400550,tapply(mean,cond,mean))

###############GLOBAL###############    
summary(lm.global <- lmer(mean~AB+CD+IJ+(1|subj),subset(datan,roi=="ant")))

##     CL       ONLY
##  -ex  +ex -ex  +ex
##   A    B   C    D
#c1 -1    1   0    0
#c2  0    0  -1    1
#c3 -1    1   1   -1
## actually only c3 is interesting

c3 <-  ifelse(datan400550$cond%in%c("101","104"),-1,
              ifelse(datan400550$cond%in%c("102","103"),1,0))

datan400550$c3 <- c3

c3 <-  ifelse(data400550$cond%in%c("101","104"),-1,
              ifelse(data400550$cond%in%c("102","103"),1,0))

data400550$c3 <- c3


xtabs(~subj+chan,datan400550)

(m0 <- lmer(mean~c3+(1|subj)+(1|chan),datan400550))
(m0a <- lmer(mean~c3+(1|subj)+(1|chan),data400550))

(m1 <- lmer(mean~c3+(1+c3|subj)+(1|chan),datan400550))
(m1a <- lmer(mean~c3+(1+c3|subj)+(1|chan),data400550))


(m2 <- lmer(mean~c3+(0+c3|subj) + (1|subj)+(1|chan),datan400550))
(m2a <- lmer(mean~c3+(0+c3|subj) + (1|subj)+(1|chan),data400550))

(m3 <- lmer(mean~c3+(0+c3|subj) + (1|subj)+(1|chan)+(0+c3|chan),datan400550))
(m3a <- lmer(mean~c3+(0+c3|subj) + (1|subj)+(1|chan)+(0+c3|chan),data400550))

(m4 <- lmer(mean~c3+(1+c3|subj)+(1|chan)+(0+c3|chan),datan400550))
(m4a <- lmer(mean~c3+(1+c3|subj)+(1|chan)+(0+c3|chan),data400550))

anova(m3,m4)

anova(m3a,m4a)

head(datan400550)

## analysis by region:
## 1=posterior, 2=central, 3=anterior

region <- ifelse(datan400550$chan%in%frontc,"3",
       ifelse(datan400550$chan%in%centralc,"2",
              ifelse(datan400550$chan%in%postc,"1",NA)))

datan400550$region <- as.factor(region)

with(datan400550,tapply(mean,IND=list(cond,region),mean))

(m0b <- lmer(mean~c3*region + (1|subj),datan400550))

# best
(m1b <- lmer(mean~c3*region + (1+c3|subj),datan400550))

(m1ba <- lmer(mean~c3*region + (0+c3|subj) + (1|subj),datan400550))

(m2b <- lmer(mean~c3*region + (1+c3+region|subj),datan400550))

anova(m0b,m1b)

anova(m1b,m2b)

anova(m1b,m1ba)

