library(psych)

library(lme4)

library(languageR)

## load all three windows:
data400550 <- read.table("Fenster/400_550.tab",header=T)
head(data400550)
data300600 <- read.table("Fenster/300_600.tab",header=T)
head(data300600)
data600800 <- read.table("600_800.tab",header=T)
head(data600800)

## combine the data into one frame:
data1 <- cbind(data300600,window="300600")
data2 <- cbind(data600800,window="600800")
data3 <- cbind(data400550,window="400550")
data <- rbind(data1,data2,data3)

## isolate critical channels
critc <- c("F3","FZ","F4","C3","CZ","C4","P3","PZ","P4")
## frontals:
frontc <- c("F3","FZ","F4")
## central:
centralc <- c("C3","CZ","C4")
# posterior:
postc <- c("P3","PZ","P4")

## add region as a factor
region <- ifelse(data$chan%in%frontc,"f",
                 ifelse(data$chan%in%centralc,"c",
                        ifelse(data$chan%in%postc,"p","other")))

data$region <- factor(region,levels=c("f","c","p","other"))

dim(data)

data <- subset(data,region!="other")

dim(data)

summary(data)

data$region <- factor(data$region)

summary(data)

## treatment contrasts for region
contrasts(data$region)

# remove implicature conditions
data <- subset(data,cond<105)

summary(data)

data$cond <- factor(data$cond)

## 101 102 103 104
## cl  cl  on  on focus type
## y   n   y   n  exhaustiveness

focustype <- factor(ifelse(data$cond%in%c(101,102),"cl","on"))
exhaustiveness <- factor(ifelse(data$cond%in%c(101,103),"ex","notex"))

data$focustype <- focustype
data$exhaustiveness <- exhaustiveness

##    101   102     103   104
##    cleft1 cleft2 only1 only2
#int  -1/2    1/2    1/2   -1/2


## checking that the recoding is correct, it is:
(means300600 <- with(subset(data,window=="300600"),
              tapply(mean,IND=list(condition,region),mean)))
(means300600 <- with(subset(data,window=="300600"),
              tapply(mean,IND=list(cond,region),mean)))

(means600800 <- with(subset(data,window=="600800"),
              tapply(mean,IND=list(condition,region),mean)))
(means600800 <- with(subset(data,window=="600800"),
              tapply(mean,IND=list(cond,region),mean)))

cleft <- ifelse(data$cond==101,-.5,
                       ifelse(data$cond==102,0.5,0))

only <- ifelse(data$cond==103,-.5,
                       ifelse(data$cond==104,0.5,0))

cleft_x_only <- ifelse(data$cond%in%c(101,104),-.5,
                       ifelse(data$cond%in%c(102,103),.5,0))

data$cleft<- cleft
data$only <- only
data$cleft_x_only <- cleft_x_only

xylowess.fnc(mean~factor(cond)|subj,layout=c(4,4),
       subset(data,window="300600"))

xylowess.fnc(mean~factor(cond)|subj,layout=c(4,4),
       subset(data,window="600800"))

is.factor(data$region)

multiplot(1,2)

barplot(means300600,
        #col = c("lightblue", "mistyrose", "lightcyan","lavender"),
        beside=T,
#        ylim=c(0,5),
#        legend=c("Cleft +ex","Cleft -ex","Only +ex","Only -ex"),
        main="300-600 ms")

barplot(means600800,beside=T,main="600-800 ms")

m36 <- rowMeans(means300600)
d1.36 <- m36[1]-m36[2]
d2.36 <- m36[3]-m36[4]
d1.36-d2.36

barplot(means600800,beside=T)

m68 <- rowMeans(means600800)
d1.68 <- m68[1]-m68[2]
d2.68 <- m68[3]-m68[4]
d1.68-d2.68

barplot(c(d1.36,d2.36,d1.68,d2.68))

library(lme4)

summary(aov(mean~focustype*exhaustiveness+Error(subj/(focustype*exhaustiveness)),data))

(m01 <- lmer(mean~focustype+exhaustiveness+(1|subj),
            subset(data,window=="300600")))

(m01 <- lmer(mean~cleft+only+(1|subj),
            subset(data,window=="400550")))

## no effect of exhaustiveness violation in clefting, but present in only
(m02 <- lmer(mean~cleft+only+(1+cleft|subj),
            subset(data,window=="400550")))

(m03 <- lmer(mean~cleft+only+(1+only|subj),
            subset(data,region!="f" & window=="300600")))

with(subset(data,region!="f" & window=="300600"),tapply(mean,cond,mean))

anova(m01,m02,m03)

(m04 <- lmer(mean~cleft_x_only+(1|subj),
            subset(data,window=="300600")))

(m05 <- lmer(mean~cleft_x_only+(1+cleft_x_only|subj),
            subset(data,window=="300600")))

anova(m04,m05)

summary(aov(mean~cleft_x_only+Error(subj/cleft_x_only),
            subset(data,window=="300600")))

summary(aov(mean~cleft_x_only+Error(subj/cleft_x_only),
            subset(data,window=="600800")))


