library(psych)

library(lme4)

library(languageR)

#library(Rcmdr)

## load all three windows:
data400550 <- read.table("Fenster/400_550.tab",header=T)
#head(data400550)
data300600 <- read.table("Fenster/300_600.tab",header=T)
head(data300600)
data600800 <- read.table("Fenster/600_800.tab",header=T)
head(data600800)
## added later, hence not in Fenster directory:
data300800 <- read.table("300800.tab",header=T)
head(data300800)

## combine the data into one frame:
data1 <- cbind(data300600,window="300600")
data2 <- cbind(data600800,window="600800")
data3 <- cbind(data400550,window="400550")
data4 <- cbind(data300800,window="300800")
data <- rbind(data1,data2,data3,data4)

## isolate critical channels
critc <- c("F3","FZ","F4","C3","CZ","C4","P3","PZ","P4")
## frontals:
frontc <- c("F3","FZ","F4")
## central:
centralc <- c("C3","CZ","C4")
# posterior:
postc <- c("P3","PZ","P4")

## add region as a factor
region <- ifelse(data$chan%in%frontc,"f",
                 ifelse(data$chan%in%centralc,"c",
                        ifelse(data$chan%in%postc,"p","other")))

data$region <- factor(region,levels=c("f","c","p","other"))

dim(data)

data <- subset(data,region!="other")

dim(data)

summary(data)

data$region <- factor(data$region)

summary(data)

## treatment contrasts for region
contrasts(data$region)

# remove implicature conditions
data <- subset(data,cond<105)

summary(data)

data$cond <- factor(data$cond)


xyplot(mean ~ cond |  subj, groups=window, pch=16,  auto.key=list(border=TRUE), par.settings = simpleTheme(pch=16),    scales=list(x=list(relation='same'), y=list(relation='same')),  data=data)

dataneu <- subset(data,window=="300600")
#data[data$window=="300600",]
xyplot(mean ~ cond |  subj, groups=region, pch=23,  auto.key=list(border=TRUE), par.settings = simpleTheme(pch=23),    scales=list(x=list(relation='same'), y=list(relation='same')),  data=dataneu)
dataneuf <- subset(dataneu,region=="f")
xyplot(mean ~ cond |  subj, groups=region, pch=23,  auto.key=list(border=TRUE), par.settings = simpleTheme(pch=23),    scales=list(x=list(relation='same'), y=list(relation='same')),  data=dataneuf)

## 101 102 103 104
## cl  cl  on  on focus type
## y   n   y   n  exhaustiveness

focustype <- factor(ifelse(data$cond%in%c(101,102),"cl","on"))
exhaustiveness <- factor(ifelse(data$cond%in%c(101,103),"ex","notex"))

data$focustype <- focustype
data$exhaustiveness <- exhaustiveness

##    101   102     103   104
##    cleft1 cleft2 only1 only2
#int  -1/2    1/2    1/2   -1/2


## checking that the recoding is correct, it is:
(means300600 <- with(subset(data,window=="300600"),
              tapply(mean,IND=list(cond,region),mean)))
(means400550 <- with(subset(data,window=="400550"),
              tapply(mean,IND=list(cond,region),mean)))

(means600800 <- with(subset(data,window=="600800"),
              tapply(mean,IND=list(cond,region),mean)))
              
(means300800 <- with(subset(data,window=="300800"),
              tapply(mean,IND=list(cond,region),mean)))

cleft <- ifelse(data$cond==101,-.5,
                       ifelse(data$cond==102,0.5,0))

only <- ifelse(data$cond==103,-.5,
                       ifelse(data$cond==104,0.5,0))

cleft_x_only <- ifelse(data$cond%in%c(101,104),-.5,
                       ifelse(data$cond%in%c(102,103),.5,0))

data$cleft<- cleft
data$only <- only
data$cleft_x_only <- cleft_x_only

xylowess.fnc(mean~factor(cond)|subj,layout=c(4,4),
       subset(data,window="300600"))
       
xylowess.fnc(mean~factor(cond)|subj,layout=c(4,4),
       subset(data,window="400550"))


xylowess.fnc(mean~factor(cond)|subj,layout=c(4,4),
       subset(data,window="600800"))
       
xylowess.fnc(mean~factor(cond)|subj,layout=c(4,4),
       subset(data,window="300800"))

is.factor(data$region)


par(mfrow = c(2, 2))

#multiplot(1,2)

barplot(means300600,
        #col = c("lightblue", "mistyrose", "lightcyan","lavender"),
        beside=T,
#        ylim=c(0,5),
#        legend=c("Cleft +ex","Cleft -ex","Only +ex","Only -ex"),
        main="300-600 ms")
barplot(means400550,beside=T,main="400-550 ms")

barplot(means600800,beside=T,main="600-800 ms")

barplot(means300800,beside=T,main="300-800 ms")

m36 <- rowMeans(means300600)
d1.36 <- m36[1]-m36[2]
d2.36 <- m36[3]-m36[4]
d1.36-d2.36

barplot(means600800,beside=T)


m455 <- rowMeans(means400550)
d1.455 <- m455[1]-m455[2]
d2.455 <- m455[3]-m455[4]
d1.455-d2.455

barplot(means400550,beside=T)


m68 <- rowMeans(means600800)
d1.68 <- m68[1]-m68[2]
d2.68 <- m68[3]-m68[4]
d1.68-d2.68

barplot(c(d1.36,d2.36,d1.68,d2.68))

library(lme4)

## begin analyses reported in paper:

(m01 <- lmer(mean~cleft+(1|subj),
            subset(data,window=="400550")))
(m02 <- lmer(mean~cleft+(1+cleft|subj),
            subset(data,window=="400550")))
anova(m01,m02)


##            


summary(aov(mean~focustype*exhaustiveness+Error(subj/(focustype*exhaustiveness)),data))

(m01 <- lmer(mean~focustype+exhaustiveness+(1|subj),
            subset(data,window=="300600")))

(m01 <- lmer(mean~cleft+only+(1|subj),
            subset(data,window=="300600")))

## no effect of exhaustiveness violation in clefting, but present in only
(m02 <- lmer(mean~cleft+only+(1+cleft|subj),
            subset(data,window=="300600")))

(m03 <- lmer(mean~cleft+only+(1+cleft+only|subj),
            subset(data,window=="300600")))

anova(m01,m02,m03)

(m04 <- lmer(mean~cleft_x_only+(1|subj),
            subset(data,window=="300600")))

(m05 <- lmer(mean~cleft_x_only+(1+cleft_x_only|subj),
            subset(data,window=="300600")))

anova(m04,m05)

summary(aov(mean~cleft_x_only+Error(subj/cleft_x_only),
            subset(data,window=="300600")))

summary(aov(mean~cleft_x_only+Error(subj/cleft_x_only),
            subset(data,window=="600800")))
            
            
(m06 <- lmer(mean~focustype+exhaustiveness+(1|subj),
            subset(data,window=="400550")))

(m07 <- lmer(mean~cleft+only+(1|subj),
            subset(data,window=="400550")))

## no effect of exhaustiveness violation in clefting, but present in only
(m08 <- lmer(mean~cleft+only+(1+cleft|subj),
            subset(data,window=="400550")))

(m09 <- lmer(mean~cleft+only+(1+cleft+only|subj),
            subset(data,window=="400550")))

anova(m06,m07,m08,m09)

(m10 <- lmer(mean~focustype+exhaustiveness+(1|subj),
            subset(data,window=="300800")))

(m11 <- lmer(mean~cleft+only+(1|subj),
            subset(data,window=="300800")))

## no effect of exhaustiveness violation in clefting, but present in only
(m12 <- lmer(mean~cleft+only+(1+cleft|subj),
            subset(data,window=="300800")))

(m13 <- lmer(mean~cleft+only+(1+cleft+only|subj),
            subset(data,window=="300800")))

anova(m10,m11,m12,m13)
